#
# spec file for package libhubbub
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%global make_vars COMPONENT_TYPE=lib-shared PREFIX=%{_prefix} LIBDIR=%{_lib} CC=cc Q=
%global build_vars OPTCFLAGS='%{optflags}' OPTLDFLAGS="$RPM_LD_FLAGS"
Name:           libhubbub
Version:        0.3.7
Release:        2.12
Summary:        An HTML5 compliant parsing library
License:        MIT
URL:            https://www.netsurf-browser.org/projects/hubbub/
Source:         http://download.netsurf-browser.org/libs/releases/%{name}-%{version}-src.tar.gz
Patch0:         0001-do-not-use-deprecated-is_error.patch
BuildRequires:  netsurf-buildsystem >= 1.1
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(json-c) >= 0.11
BuildRequires:  pkgconfig(libparserutils) >= 0.2.0

%description
Hubbub is an HTML5 compliant parsing library, written in C. It was
developed as part of the NetSurf project.

%package -n libhubbub0
Summary:        An HTML5 compliant parsing library

%description -n libhubbub0
Hubbub is an HTML5 compliant parsing library, written in C. It was
developed as part of the NetSurf project.

The HTML5 specification defines a parsing algorithm, based on the
behaviour of mainstream browsers, which provides instructions for how to
parse all markup, both valid and invalid. As a result, Hubbub parses web
content well.

Features:
* Parses HTML, good and bad
* Simple C API
* Fast
* Character encoding detection
* Well-tested (~90% test coverage)
* Portable

%package devel
Summary:        Development files for %{name}
Requires:       libhubbub0 = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

sed -i -e s@-Werror@@ Makefile

%build
%make_build %{make_vars} %{build_vars}

%install
%make_install %{make_vars}

%post -n libhubbub0 -p /sbin/ldconfig
%postun -n libhubbub0 -p /sbin/ldconfig

%check
%make_build test %{make_vars} %{build_vars}

%files -n libhubbub0
%license COPYING
%{_libdir}/%{name}.so.*

%files devel
%{_includedir}/hubbub
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Wed May 19 2021 Fridrich Strba <fstrba@suse.com>
- Define conditionally make_build to fix build on systems that do
  not have that macro
* Wed Sep  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.7:
  * Fixes build with new netsurf-buildsystem pkg
- Remove non applicable patches:
  * 0001-workaround-fail-on-ppc64.patch
- Do not bother with doxygen as the docu is online:
  * libhubbub-0.3.0-notimestamp.patch
* Mon Jul  6 2020 Fridrich Strba <fstrba@suse.com>
- Removed patch:
  * libhubbub-0.3.0-is_error.patch
    + json-c/bits.h does not exist in newer json-c versions
  * 0001-do-not-use-deprecated-is_error.patch
    + Do not use deprecated is_error
    + Fixes build of tests
* Fri Jan 12 2018 fstrba@suse.com
- Added patch:
  * libhubbub-0.3.0-is_error.patch
    + Avoid implicit declaration and undefined symbol "is_error"
* Tue Aug  8 2017 jengelh@inai.de
- Fix RPM groups.
* Thu Jul 31 2014 dvaleev@suse.com
- Workaround false positive on powerpc64 (bnc#889740)
- added patches:
  * 0001-workaround-fail-on-ppc64.patch
* Fri May 23 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
* Fri May 23 2014 fstrba@suse.com
- Initial import of libhubbub, inspired by Fedora package
- Add patch to not store timestamp in package:
  * libhubbub-0.3.0-notimestamp.patch
